@@ -12,7 +12,7 @@ use Sub::Exporter -setup => {
 
 our @ISA = qw();
 
-our $VERSION = '0.30'; # VERSION
+our $VERSION = 0.31;
 
 sub show_bar {
     my $num     = shift || 0;
@@ -72,14 +72,13 @@ sub max_label_width {
 }
 
 1;
-
 __END__
 
-=pod
+=encoding utf-8
 
 =head1 NAME
 
-Term::Vspark
+Term::Vspark - Displays a graph in the terminal
 
 =head1 SYNOPSIS
 
@@ -100,6 +99,7 @@ Term::Vspark
     # 4 ███████████████████████████████████████████▌
     # 5 ██████████████████████████████████████████████████████▍
 
+
 =head1 DESCRIPTION
 
 This module displays beautiful graphs in the terminal.  It is a companion to
@@ -109,17 +109,11 @@ sparklines.
 Note that because the graph is built from utf8 characters, users must setup
 UTF-8 encoding for STDOUT if they wish to print the output.
 
-=encoding utf-8
-
-=head1 NAME
-
-Term::Vspark - Displays a graph in the terminal
-
 =head1 METHODS
 
-=head2 show_graph( values => \@values, labels => \@labels, max => $max, columns => $columns )
+=head2 show_graph(%params)
 
-show_graph returns a string.
+show_graph() returns a string.
 
 The 'values' parameter should be an ArrayRef of numbers.   This is required.
 
@@ -132,21 +126,11 @@ data.  This parameter is optional.
 
 The 'columns' parameter is the maximum width of the graph.
 
-=head1 SEE ALSO
-
-L<Term::Spark>
-
-Original repo: L<https://github.com/LuRsT/vspark>
-
 =head1 AUTHOR
 
 Gil Gonçalves <lurst@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 SEE ALSO
 
-This software is copyright (c) 2013 by Gil Gonçalves.
+L<Term::Spark>
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
